From 9f106ce2beaf0f6f966c55fd8a3733e86fe2d988 Mon Sep 17 00:00:00 2001
From: Olivier Maury <Olivier.Maury@inrae.fr>
Date: Fri, 31 Jan 2025 16:49:33 +0100
Subject: [PATCH] style: corrections orthographiques

---
 .../java/fr/soeretempo/sido/cli/MainSido.java | 10 +++---
 .../CreateScriptSchema.java                   |  4 +--
 .../sido/gwt/client/home/HomeView.java        |  2 +-
 .../ManageDatasourceViewImpl.java             |  4 +--
 .../datasetadmin/DatasetAdminModal.java       |  6 ++--
 .../datasourceadmin/DatasourceAdminModal.java |  6 ++--
 .../ListWorkbooksViewImpl.ui.xml              |  2 +-
 .../managedataset/ManageDatasetView.java      |  2 +-
 .../managedataset/ManageDatasetViewImpl.java  |  4 +--
 .../gwt/client/preview/PreviewViewImpl.ui.xml |  2 +-
 .../gwt/client/profile/MailEditModal.java     |  2 +-
 .../gwt/client/profile/ProfileViewImpl.java   |  2 +-
 .../gwt/client/profile/ProfileViewImpl.ui.xml |  2 +-
 .../gwt/client/resources/SidoConstants.java   | 15 ++++----
 .../client/service/VerificationService.java   |  3 +-
 .../sido/gwt/client/ui/ImageAnchor.java       |  2 +-
 .../verification/VerificationViewImpl.java    |  8 ++---
 .../verification/VerificationViewImpl.ui.xml  |  2 +-
 .../sido/gwt/server/DataTransferts.java       |  3 +-
 .../sido/gwt/server/dao/DatasetDaoImpl.java   |  1 -
 .../server/dao/InsertDataDaoHibernate.java    |  2 +-
 .../dataverseclient/DataverseHandler.java     | 12 +++----
 .../downloadfile/FileDownloadServlet.java     |  2 +-
 .../soeretempo/sido/gwt/server/mail/Mail.java | 15 ++++----
 .../sido/gwt/server/mail/MailService.java     | 35 ++++++++++---------
 .../sido/gwt/server/metadata/EMLUtils.java    |  4 +--
 .../gwt/server/metadata/MetadataHandler.java  |  4 +--
 .../gwt/server/metadata/MetadataParser.java   |  5 ++-
 .../server/openid/OpenIdCallbackServlet.java  |  2 +-
 .../sido/gwt/server/package-info.java         |  2 +-
 .../service/VerificationServiceImpl.java      |  6 ++--
 .../server/service/WorkbooksServiceImpl.java  |  6 ++--
 .../gwt/shared/dto/DatasetCreationReport.java |  4 +--
 .../sido/gwt/shared/dto/DatasetDTO.java       |  4 +--
 .../gwt/shared/dto/DatasourceRefreshDTO.java  |  4 +--
 .../sido/gwt/shared/dto/PreviewDTO.java       |  4 +--
 .../sido/gwt/shared/dto/WorkbooksDataDTO.java |  2 +-
 .../sido/gwt/shared/dto/package-info.java     |  2 +-
 .../resources/SidoConstants_fr.properties     |  4 +--
 .../gwt/server/resources/messages.properties  |  4 +--
 .../server/resources/messages_fr.properties   | 23 ++++++++++--
 .../sido/verification/OutilsVerifXML.java     | 24 ++++++-------
 .../sido/verification/Verification.java       | 12 +++----
 .../resources/messages.properties             |  2 +-
 .../resources/messages_fr.properties          |  2 +-
 .../sido/verification/OutilsVerifXMLTest.java |  4 +--
 46 files changed, 144 insertions(+), 128 deletions(-)

diff --git a/sido-cli/src/main/java/fr/soeretempo/sido/cli/MainSido.java b/sido-cli/src/main/java/fr/soeretempo/sido/cli/MainSido.java
index ef47c14e..14eecc4f 100644
--- a/sido-cli/src/main/java/fr/soeretempo/sido/cli/MainSido.java
+++ b/sido-cli/src/main/java/fr/soeretempo/sido/cli/MainSido.java
@@ -205,7 +205,7 @@ public class MainSido {
                 boolean noErrorXML = true;
                 for (int i = 0; i < listIndF.size(); i++) {
 
-                    if (!verifXML.listIgnorSheet().contains(listIndF.get(i))) {
+                    if (!verifXML.getIgnoredSheets().contains(listIndF.get(i))) {
                         // liste des erreurs pour la vérification des données.
                         final List<String> listF = ver.verifData(listIndF.get(i));
                         if (!listF.isEmpty()) {
@@ -265,17 +265,17 @@ public class MainSido {
                     + " pour le(s) champ(s) [{}].", verifXml.getFileName(), verifXml.validTypeValuesXMLFile());
             LOGGER.info(LINE_SEPARATOR2);
         }
-        if (verifXml.validMissingVAlueXMLFile() != null) {
+        if (verifXml.validMissingValueInXmlLFile() != null) {
             LOGGER.info(LINE_SEPARATOR2);
             LOGGER.info(
                     "Le fichier '{}' contient des valeurs non acceptées dans la balise 'missingValuesAccepted' [{}].",
-                    verifXml.getFileName(), verifXml.validMissingVAlueXMLFile());
+                    verifXml.getFileName(), verifXml.validMissingValueInXmlLFile());
             LOGGER.info(LINE_SEPARATOR2);
         }
-        if (verifXml.validUniqueVAlueXMLFile() != null) {
+        if (verifXml.validUniqueValueInXmlFile() != null) {
             LOGGER.info(LINE_SEPARATOR2);
             LOGGER.info("Le fichier '{}' contient des valeurs non acceptées dans la balise 'unique' [{}].",
-                    verifXml.getFileName(), verifXml.validUniqueVAlueXMLFile());
+                    verifXml.getFileName(), verifXml.validUniqueValueInXmlFile());
             LOGGER.info(LINE_SEPARATOR2);
         }
         if (verifXml.validTagNameXMLFile() != null) {
diff --git a/sido-createSchemaTable/src/main/java/fr/soeretempo/sido/createSchemaTables/CreateScriptSchema.java b/sido-createSchemaTable/src/main/java/fr/soeretempo/sido/createSchemaTables/CreateScriptSchema.java
index 8b823e4c..8591e4fc 100644
--- a/sido-createSchemaTable/src/main/java/fr/soeretempo/sido/createSchemaTables/CreateScriptSchema.java
+++ b/sido-createSchemaTable/src/main/java/fr/soeretempo/sido/createSchemaTables/CreateScriptSchema.java
@@ -248,7 +248,7 @@ public class CreateScriptSchema {
     public static String createTables(final WorkbookXML workbook,
             final File fileXml, final String schemaName) throws JAXBException {
         final OutilsVerifXML verifXml = new OutilsVerifXML(fileXml);
-        final List<String> listSheetIgnored = verifXml.listIgnorSheet();
+        final List<String> listSheetIgnored = verifXml.getIgnoredSheets();
         final int workSheetSize = workbook.getWorksheet().size();
         LOGGER.info("workbook contains " + workSheetSize + " sheet(s)");
         LOGGER.info("sheet(s) name ignored " + listSheetIgnored);
@@ -335,7 +335,7 @@ public class CreateScriptSchema {
             final File xmlFile, final String schemaName) throws JAXBException {
         final OutilsVerifXML verifXml = new OutilsVerifXML(xmlFile);
         final List<String> listSheetNotIgnored = verifXml
-                .listNotIgnorSheetBDD();
+                .getDbTableNamesOfNotIgnoredSheets();
         final StringBuilder dropTables = new StringBuilder();
         dropTables.append("DROP TABLE IF EXISTS ");
         for (int j = 0; j < listSheetNotIgnored.size(); j++) {
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/home/HomeView.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/home/HomeView.java
index 52e0d7c4..fff262ba 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/home/HomeView.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/home/HomeView.java
@@ -61,7 +61,7 @@ public interface HomeView extends IsWidget {
     void setPresenter(PresenterHome presenter);
 
     /**
-     * An unknown error has occured. Relocate to home and reload SIDO.
+     * An unknown error has occurred. Relocate to home and reload SIDO.
      */
     void showErrorAlert();
 
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/ManageDatasourceViewImpl.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/ManageDatasourceViewImpl.java
index baadf6c0..c4d6846f 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/ManageDatasourceViewImpl.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/ManageDatasourceViewImpl.java
@@ -438,7 +438,7 @@ public class ManageDatasourceViewImpl extends Composite implements ManageDatasou
     }
 
     /**
-     * Button handler registration to strenghten security.
+     * Button handler registration to strengthen security.
      */
     private HandlerRegistration datasourceManagementRegistration = null;
 
@@ -526,7 +526,7 @@ public class ManageDatasourceViewImpl extends Composite implements ManageDatasou
                 if (manager.getEmail() != null && !manager.getEmail().isEmpty()) {
                     text.append(" (").append(manager.getEmail()).append(")");
                 } else {
-                    text.append(" (").append(constants.noEmailAdress()).append(")");
+                    text.append(" (").append(constants.noEmailAddress()).append(")");
                 }
                 sj.add(text.toString());
             }
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/listworkbooks/ListWorkbooksViewImpl.ui.xml b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/listworkbooks/ListWorkbooksViewImpl.ui.xml
index 0e91f35e..ca301820 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/listworkbooks/ListWorkbooksViewImpl.ui.xml
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/listworkbooks/ListWorkbooksViewImpl.ui.xml
@@ -42,7 +42,7 @@
 							ui:field="dataGridWorkbook" />
 					</b:Form>
 					<b:Button ui:field="insertWorkbookBtn"
-						text="{csts.insertWorkbook}" type="PRIMARY" color="whith"
+						text="{csts.insertWorkbook}" type="PRIMARY" color="white"
 						icon="PLUS" />
 				</b:PanelBody>
 			</b:Panel>
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/managedataset/ManageDatasetView.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/managedataset/ManageDatasetView.java
index d58eae0b..78a1c469 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/managedataset/ManageDatasetView.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/managedataset/ManageDatasetView.java
@@ -124,7 +124,7 @@ public interface ManageDatasetView extends IsWidget, Serializable {
     void ungrayButton();
 
     /**
-     * Update the dataset status in the client after a successfull update on the server.
+     * Update the dataset status in the client after a successful update on the server.
      * @param status new dataset status
      * @param updated last update
      */
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/managedataset/ManageDatasetViewImpl.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/managedataset/ManageDatasetViewImpl.java
index 2d8a13fb..39541795 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/managedataset/ManageDatasetViewImpl.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/managedataset/ManageDatasetViewImpl.java
@@ -591,8 +591,8 @@ public class ManageDatasetViewImpl extends Composite implements ManageDatasetVie
         if (dataset != null && uploadField.getFilename() != null) {
             uploadFieldButton.setEnabled(false);
             final String fileName = uploadField.getFilename();
-            final String extention = fileName.substring(fileName.lastIndexOf("."));
-            if (extention.equalsIgnoreCase(".xls") || extention.equalsIgnoreCase(".xlsx")) {
+            final String extension = fileName.substring(fileName.lastIndexOf("."));
+            if (extension.equalsIgnoreCase(".xls") || extension.equalsIgnoreCase(".xlsx")) {
                 loadingGif.setVisible(true);
                 form.submit();
                 uploadField.setEnabled(false);
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/preview/PreviewViewImpl.ui.xml b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/preview/PreviewViewImpl.ui.xml
index 27e052d7..04d38d53 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/preview/PreviewViewImpl.ui.xml
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/preview/PreviewViewImpl.ui.xml
@@ -39,7 +39,7 @@
 						<b:ListBox ui:field="lstBoxSheet" />
 						<b:Button ui:field="previewSheetDataBtn" icon="EYE"
 							marginLeft="15" text="{csts.previewSheet}" type="PRIMARY"
-							color="whith" />
+							color="white" />
 					</b:PanelGroup>
 					<g:ScrollPanel ui:field="scrolPanel"
 						styleName="{res.css.previewScrollPanel}">
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/MailEditModal.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/MailEditModal.java
index 0758e510..54885fd8 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/MailEditModal.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/MailEditModal.java
@@ -130,7 +130,7 @@ public final class MailEditModal extends Composite {
         initWidget(uiBinder.createAndBindUi(this));
         user = account;
         if (account.getEmail() == null || account.getEmail().isEmpty()) {
-            previousMail.setText(CONSTANTS.noEmailAdress());
+            previousMail.setText(CONSTANTS.noEmailAddress());
         } else {
             previousMail.setText(account.getEmail());
         }
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/ProfileViewImpl.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/ProfileViewImpl.java
index 1f374f04..39f57cb0 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/ProfileViewImpl.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/ProfileViewImpl.java
@@ -209,7 +209,7 @@ public final class ProfileViewImpl extends Composite implements ProfileView {
         organization.setText(user.getOrganization());
         created.setText(user.getCreated());
         if (user.getEmail() == null || user.getEmail().isEmpty()) {
-            email.setText(CST.noEmailAdress());
+            email.setText(CST.noEmailAddress());
         } else {
             email.setText(user.getEmail());
         }
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/ProfileViewImpl.ui.xml b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/ProfileViewImpl.ui.xml
index 205aad2e..392a9d62 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/ProfileViewImpl.ui.xml
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/profile/ProfileViewImpl.ui.xml
@@ -7,7 +7,7 @@
 	Public License for more details. You should have received a copy of the GNU
 	General Public License along with Tempo. If not, see <https://www.gnu.org/licenses/>. -->
 <!DOCTYPE ui:UiBinder SYSTEM "http://dl.google.com/gwt/DTD/xhtml.ent">
-<!-- Display profile informations, and actions. -->
+<!-- Display profile information, and actions. -->
 <!-- Last changed : $Date: 2018-06-22 15:41:29 +0200 (ven., 22 juin 2018)
 	$ -->
 <!-- @author $Author: ltromel $ -->
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/resources/SidoConstants.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/resources/SidoConstants.java
index fdabdcd7..5c1c29f6 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/resources/SidoConstants.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/resources/SidoConstants.java
@@ -232,7 +232,7 @@ public interface SidoConstants extends Constants {
     /**
      * @return datasetInfos
      */
-    @DefaultStringValue("Informations about the dataset")
+    @DefaultStringValue("Information about the dataset")
     String datasetInfos();
 
     /**
@@ -743,7 +743,7 @@ public interface SidoConstants extends Constants {
     /**
      * @return showMoreInfos
      */
-    @DefaultStringValue("Show more informations about the dataset")
+    @DefaultStringValue("Show more information about the dataset")
     String showMoreInfos();
 
     /**
@@ -859,8 +859,9 @@ public interface SidoConstants extends Constants {
     /**
      * @return Valid workbook
      */
+    // TODO use Message
     @DefaultStringValue("Your workbook(s) have been inserted")
-    String valideWorkbook();
+    String validWorkbook();
 
     /**
      * @return Webservices
@@ -930,10 +931,10 @@ public interface SidoConstants extends Constants {
     String workbookCount();
 
     /**
-     * @return noEmailAdress
+     * @return translation
      */
-    @DefaultStringValue("No e-mail")
-    String noEmailAdress();
+    @DefaultStringValue("No e-mail address")
+    String noEmailAddress();
 
     /**
      * @return manageDatasetUsers
@@ -1010,7 +1011,7 @@ public interface SidoConstants extends Constants {
     /**
      * @return profileDownloadDataConfirmTitle
      */
-    @DefaultStringValue("Download personnal data")
+    @DefaultStringValue("Download personal data")
     String profileDownloadDataConfirmTitle();
 
     /**
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/service/VerificationService.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/service/VerificationService.java
index 729430d4..7d334342 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/service/VerificationService.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/service/VerificationService.java
@@ -45,9 +45,8 @@ public interface VerificationService extends RemoteService {
     /**
      * Retrieve dataset data.
      * @param datasetId
-     * @return a DatasetDTO for the gived ID
+     * @return a DatasetDTO for the given ID
      */
     DatasetDTO getDataset(String datasetId);
 
-
 }
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/ui/ImageAnchor.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/ui/ImageAnchor.java
index 9acc5b05..0bdb31b8 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/ui/ImageAnchor.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/ui/ImageAnchor.java
@@ -177,7 +177,7 @@ public final class ImageAnchor extends Anchor implements HasType<ImageType> {
     /**
      * Sets the url and the visibility rectangle for the image at the same time,
      * based on an ImageResource instance. A single load event will be fired if
-     * either the incoming url or visiblity rectangle co-ordinates differ from
+     * either the incoming url or visibility rectangle co-ordinates differ from
      * the image's current url or current visibility rectangle co-ordinates. If
      * the image is currently in the unclipped state, a call to this method will
      * cause a transition to the clipped state.
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/verification/VerificationViewImpl.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/verification/VerificationViewImpl.java
index a5414f1a..3c42d514 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/verification/VerificationViewImpl.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/verification/VerificationViewImpl.java
@@ -291,10 +291,10 @@ public class VerificationViewImpl extends Composite implements VerificationView
         final String[] fileNames = getFileNames(uploadField.getElement());
         boolean correctExtensions = true;
         for (final String fileName : fileNames) {
-            final String extention = fileName.substring(fileName.lastIndexOf("."));
-            if (extention.equals("")
-                    || !extention.equalsIgnoreCase(".xls")
-                    && !extention.equalsIgnoreCase(".xlsx")) {
+            final String extension = fileName.substring(fileName.lastIndexOf("."));
+            if (extension.equals("")
+                    || !extension.equalsIgnoreCase(".xls")
+                    && !extension.equalsIgnoreCase(".xlsx")) {
                 correctExtensions = false;
                 GWT.log("Bad extension: " + fileName);
             }
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/verification/VerificationViewImpl.ui.xml b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/verification/VerificationViewImpl.ui.xml
index 817dbc51..15651a6e 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/verification/VerificationViewImpl.ui.xml
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/verification/VerificationViewImpl.ui.xml
@@ -79,7 +79,7 @@
 					<b:Heading ui:field="verifErrors" size="H1" color="red"
 						text="{csts.errorsWorkbook}"></b:Heading>
 					<b:Heading ui:field="verifNoErrors" visible="false"
-						color="green" size="H1" text="{csts.valideWorkbook}"></b:Heading>
+						color="green" size="H1" text="{csts.validWorkbook}"></b:Heading>
 				</b:PanelHeader>
 				<b:PanelBody ui:field="verifErrorsBody">
 					<g:ScrollPanel ui:field="scrollPanel"
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/DataTransferts.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/DataTransferts.java
index a6561de5..db6f8208 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/DataTransferts.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/DataTransferts.java
@@ -41,6 +41,7 @@ import fr.soeretempo.sido.gwt.shared.dto.WorkbookDTO;
 /**
  * @author melhasnaoui
  */
+// TODO DataTransfers
 public final class DataTransferts {
 
     /**
@@ -168,7 +169,7 @@ public final class DataTransferts {
     private static final int USERNAME = 3;
 
     /**
-     * Tranforms an array exported with fields in order from the db to an usable DTO.
+     * Transforms an array exported with fields in order from the db to an usable DTO.
      * @param entity
      *            workbook
      * @return data interface Table workbook
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dao/DatasetDaoImpl.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dao/DatasetDaoImpl.java
index e2745464..a65b76c6 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dao/DatasetDaoImpl.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dao/DatasetDaoImpl.java
@@ -19,7 +19,6 @@ package fr.soeretempo.sido.gwt.server.dao;
 
 import java.sql.Timestamp;
 import java.time.LocalDateTime;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicInteger;
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dao/InsertDataDaoHibernate.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dao/InsertDataDaoHibernate.java
index 87145d40..20c26ad5 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dao/InsertDataDaoHibernate.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dao/InsertDataDaoHibernate.java
@@ -224,7 +224,7 @@ public class InsertDataDaoHibernate implements InsertDataDao {
             LOGGER.info("If something went wrong here, it is presumably because administrator missed a column in "
                     + "the .xml filled, or made a a mistake in the name of a column. When you see \"ERROR: INSERT "
                     + "has more expressions than target columns\", there is a parameter which SIDO doesn't know "
-                    + "the column, or column name is mispelled, so there is too much params for declared columns "
+                    + "the column, or column name is misspelled, so there is too much params for declared columns "
                     + "as a result. Please check you model.xml file. This can be caused also by leaving a "
                     + "constraint on database which is no longer present in the .xml (bounds for example).");
             LOGGER.catching(e);
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dataverseclient/DataverseHandler.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dataverseclient/DataverseHandler.java
index b8145f1e..3a86988a 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dataverseclient/DataverseHandler.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/dataverseclient/DataverseHandler.java
@@ -373,7 +373,7 @@ public class DataverseHandler implements Runnable {
             LOGGER.trace(resp.toString());
             return resp;
         } catch (final RestClientException e) {
-            mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionnalInfos(dataset, null));
+            mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionalInfos(dataset, null));
             LOGGER.catching(e);
             throw new ReachDataverseException();
         }
@@ -429,17 +429,17 @@ public class DataverseHandler implements Runnable {
                     }
                 } catch (final JAXBException e) {
                     LOGGER.error("Could not create eml file.");
-                    mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionnalInfos(dataset, null));
+                    mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionalInfos(dataset, null));
                     LOGGER.catching(e);
                     authorized = false;
                 } catch (final ModelParamIncoherenceException e) {
                     LOGGER.error("Model files seems not well configured.");
-                    mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionnalInfos(dataset, null));
+                    mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionalInfos(dataset, null));
                     LOGGER.catching(e);
                     authorized = false;
                 } catch (final IOException e) {
-                    LOGGER.error("An unknown error occured when parsing metadata, or uploading eml file.");
-                    mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionnalInfos(dataset, null));
+                    LOGGER.error("An unknown error occurred when parsing metadata, or uploading eml file.");
+                    mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionalInfos(dataset, null));
                     LOGGER.catching(e);
                     authorized = false;
                 } catch (final ReachDataverseException e) {
@@ -485,7 +485,7 @@ public class DataverseHandler implements Runnable {
         try {
             dataverseOps.uploadNativeFile(emlBytes, metadata, identifier, "metadata.xml");
         } catch (final RestClientException e) {
-            mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionnalInfos(dataset, null));
+            mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionalInfos(dataset, null));
             throw new ReachDataverseException();
         }
         LOGGER.traceExit();
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/downloadfile/FileDownloadServlet.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/downloadfile/FileDownloadServlet.java
index ad428adc..d12e4dc4 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/downloadfile/FileDownloadServlet.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/downloadfile/FileDownloadServlet.java
@@ -142,7 +142,7 @@ public class FileDownloadServlet extends AbstractServlet {
                         LOGGER.warn("File not found at " + filePath);
                         response.setContentType(CONTENT_TYPE_TEXT_PLAIN);
                         response.sendError(HttpServletResponse.SC_NOT_FOUND,
-                                i18n.get("msgDowloadFileProblem"));
+                                i18n.get("msgDownloadFileProblem"));
                         return;
                     }
                     writeFile(downloadFile, fileName, response);
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/mail/Mail.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/mail/Mail.java
index f5c159ff..fec7eb31 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/mail/Mail.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/mail/Mail.java
@@ -34,7 +34,7 @@ public final class Mail {
     /**
      * Attachments.
      */
-    private List<String> mailAttachements = new ArrayList<>();
+    private List<String> mailAttachments = new ArrayList<>();
 
     /**
      * Character set definition.
@@ -161,10 +161,10 @@ public final class Mail {
     }
 
     /**
-     * @return list of mailAttachements
+     * @return list of attachments
      */
-    public List<String> getAttachements() {
-        return Collections.unmodifiableList(mailAttachements);
+    public List<String> getAttachments() {
+        return Collections.unmodifiableList(mailAttachments);
     }
 
     /**
@@ -231,11 +231,12 @@ public final class Mail {
     }
 
     /**
-     * @param attachements
+     * @param attachments
      *            attachments
      */
-    public void setAttachements(final List<String> attachements) {
-        this.mailAttachements = attachements;
+    // TODO setAttachments
+    public void setAttachments(final List<String> attachments) {
+        this.mailAttachments = attachments;
     }
 
     /**
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/EMLUtils.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/EMLUtils.java
index 5dedf659..85dd9354 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/EMLUtils.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/EMLUtils.java
@@ -348,7 +348,7 @@ public final class EMLUtils {
         dataset.getAdditionalInfo().add(subtitleTextType);
 
         // Additional info
-        final SectionType addInfoSection = new SectionType("Additional informations");
+        final SectionType addInfoSection = new SectionType("Additional information");
         addInfoSection.getParaOrSection().add(new ParagraphType(facade.getNote()));
         final TextType addInfoTextType = textFactory.createTextType();
         addInfoTextType.getContent().add(textFactory.createTextTypeSection(addInfoSection));
@@ -472,7 +472,7 @@ public final class EMLUtils {
                 dataTable.getPhysical().add(physical);
                 datatables.add(dataTable);
             } catch (final JAXBException e) {
-                LOGGER.error("An error occured reading the file" + entry.getKey());
+                LOGGER.error("An error occurred reading the file {}", entry.getKey());
                 LOGGER.catching(e);
                 throw e;
             }
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/MetadataHandler.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/MetadataHandler.java
index 1444b7cf..c5d92cde 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/MetadataHandler.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/MetadataHandler.java
@@ -109,12 +109,12 @@ public class MetadataHandler {
             if (parser.getMetadataReport().getDatasetFacade() == null) {
                 throw new IOException("The DatasetFacade should not be null !");
             } else {
-                parser.parseAdditionnalMetadata(dataset, mappedColumns);
+                parser.parseAdditionalMetadata(dataset, mappedColumns);
             }
         } catch (final JAXBException | IOException e) {
             parser.getMetadataReport().addErrors(Arrays.asList("Something went wrong reading the parameter file (.xml)"
                     + " on the server. Please contact SIDO administration."));
-            mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionnalInfos(dataset, null));
+            mailService.errorMail(e, config.get(Key.APP_URL), mailService.getAdditionalInfos(dataset, null));
             LOGGER.catching(e);
         }
         LOGGER.traceExit();
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/MetadataParser.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/MetadataParser.java
index 414c9c56..8d060951 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/MetadataParser.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/metadata/MetadataParser.java
@@ -93,11 +93,10 @@ public class MetadataParser {
     private MetadataReport metadataReport = new MetadataReport();
 
     /**
-     * Internationalization ressource class.
+     * Internationalization resource class.
      */
     private final I18n i18n;
 
-
     /**
      * First column number to parse from excel metadata sheet.
      */
@@ -859,7 +858,7 @@ public class MetadataParser {
         facadeBuilder.languages(languages);
     }
 
-    public final void parseAdditionnalMetadata(final Dataset dataset,
+    public final void parseAdditionalMetadata(final Dataset dataset,
             final Map<String, String[]> mappedColumns) {
         if (mappedColumns.containsKey(FieldNameXML.DATE)) {
             setTimePeriodCovered(dataset, mappedColumns);
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/openid/OpenIdCallbackServlet.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/openid/OpenIdCallbackServlet.java
index 5ccfdfb3..34a82ef5 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/openid/OpenIdCallbackServlet.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/openid/OpenIdCallbackServlet.java
@@ -202,7 +202,7 @@ public class OpenIdCallbackServlet extends HttpServlet {
             logError(e, response, "Can't retrieve tokens !", SERVER_ERROR);
             return;
         }
-        // finally gets user informations
+        // finally gets user information
         final UserInfo userInfo;
         try {
             userInfo = getUserInfo(providerMetadata, tokens);
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/package-info.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/package-info.java
index 1ad58ac5..90aff475 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/package-info.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/package-info.java
@@ -16,7 +16,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 /**
- * RPC of the GWT, Filter, DataTransferts.
+ * RPC of the GWT, Filter, DataTransfers.
  * @author melhasnaoui
  */
 package fr.soeretempo.sido.gwt.server;
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/service/VerificationServiceImpl.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/service/VerificationServiceImpl.java
index 9c7d23a0..9547ab44 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/service/VerificationServiceImpl.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/service/VerificationServiceImpl.java
@@ -158,7 +158,7 @@ public class VerificationServiceImpl extends AbstractRemoteServiceServlet implem
             LOGGER.trace("Shema and xml worksheet loaded");
             final int lstWorkSheetSize = worksheetList.size();
             res.append("<ul><li><b>" + i18n.format(lstWorkSheetSize, "dataInserted") + "</b></br><ul>");
-            final List<String> listSheetIgnored = verifXML.listIgnorSheet();
+            final List<String> listSheetIgnored = verifXML.getIgnoredSheets();
             LOGGER.trace("Ignored sheet loaded");
             boolean inserted = false;
             for (int i = 0; i < lstWorkSheetSize; i++) {
@@ -194,7 +194,7 @@ public class VerificationServiceImpl extends AbstractRemoteServiceServlet implem
     }
 
     /**
-     * Asbtract to be displayed before logs returned to user.
+     * Abstract to be displayed before logs returned to user.
      */
     private final StringBuilder abstractResume = new StringBuilder();
 
@@ -227,7 +227,7 @@ public class VerificationServiceImpl extends AbstractRemoteServiceServlet implem
                     backLog.add(insertWorkbook(workbookName, user, workbookDataset, i18n, locale));
                 } catch (final RuntimeException | IOException e) {
                     sendMail.errorMail(e, config.get(Key.APP_URL),
-                            sendMail.getAdditionnalInfos(workbookDataset, getUser()));
+                            sendMail.getAdditionalInfos(workbookDataset, getUser()));
                     LOGGER.catching(e);
                     backLog.add("An error has occured inserting " + workbookName + " that can't be described."
                             + " See server logs for more details.");
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/service/WorkbooksServiceImpl.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/service/WorkbooksServiceImpl.java
index 27269254..6dd791ec 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/service/WorkbooksServiceImpl.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/service/WorkbooksServiceImpl.java
@@ -144,7 +144,7 @@ implements WorkbooksService {
             }
         } catch (final Exception e) {
             mailservice.errorMail(e, config.get(Key.APP_URL),
-                    sendMail.getAdditionnalInfos(work.getDataset(), getUser()));
+                    sendMail.getAdditionalInfos(work.getDataset(), getUser()));
             LOGGER.catching(e);
             var = "";
             var += i18n.format("msgDeleteWorkbookProblem");
@@ -202,7 +202,7 @@ implements WorkbooksService {
             dataSheet.setColumnNames(lstSheet);
         } catch (JAXBException | InvalidFormatException e) {
             mailservice.errorMail(e, config.get(Key.APP_URL),
-                    mailservice.getAdditionnalInfos(workbook.getDataset(), getUser()));
+                    mailservice.getAdditionalInfos(workbook.getDataset(), getUser()));
             LOGGER.catching(e);
         }
         LOGGER.traceExit();
@@ -221,7 +221,7 @@ implements WorkbooksService {
             if (!pathFileXml.equals("")) {
                 try {
                     lstSheet = new OutilsVerifXML(pathFileXml)
-                            .listNotIgnorSheet();
+                            .getNotIgnoredSheets();
                 } catch (final JAXBException e) {
                     LOGGER.trace(e.getErrorCode());
                 }
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasetCreationReport.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasetCreationReport.java
index 13232370..453ddfc2 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasetCreationReport.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasetCreationReport.java
@@ -23,9 +23,9 @@ import java.util.List;
 import lombok.ToString;
 
 /**
- * Dataset Data Transfert Object.
- * @author ltromel
+ * Dataset Data Transfer Object.
  *
+ * @author ltromel
  */
 @ToString
 public class DatasetCreationReport
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasetDTO.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasetDTO.java
index a1833508..a475f482 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasetDTO.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasetDTO.java
@@ -24,9 +24,9 @@ import fr.soeretempo.sido.gwt.shared.DatasetStatus;
 import lombok.ToString;
 
 /**
- * Dataset Data Transfert Object.
- * @author ltromel
+ * Dataset Data Transfer Object.
  *
+ * @author ltromel
  */
 @ToString
 public class DatasetDTO
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasourceRefreshDTO.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasourceRefreshDTO.java
index 1716641b..4928a29d 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasourceRefreshDTO.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/DatasourceRefreshDTO.java
@@ -21,9 +21,9 @@ import java.io.Serializable;
 import java.util.List;
 
 /**
- * Dataset Data Transfert Object.
- * @author ltromel
+ * Dataset Data Transfer Object.
  *
+ * @author ltromel
  */
 public class DatasourceRefreshDTO
 implements Serializable {
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/PreviewDTO.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/PreviewDTO.java
index df30a319..d2bd07f5 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/PreviewDTO.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/PreviewDTO.java
@@ -23,9 +23,9 @@ import java.util.List;
 import lombok.ToString;
 
 /**
- * Dataset Data Transfert Object.
- * @author ltromel
+ * Dataset Data Transfer Object.
  *
+ * @author ltromel
  */
 @ToString
 public class PreviewDTO implements Serializable {
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/WorkbooksDataDTO.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/WorkbooksDataDTO.java
index 2a8ad43b..4fa43670 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/WorkbooksDataDTO.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/WorkbooksDataDTO.java
@@ -23,7 +23,7 @@ import java.util.List;
 import lombok.ToString;
 
 /**
- * Workbooks and Dataset Data Transfert Object to use in ListWorkbooksView / Activity and callbacks.
+ * Workbooks and Dataset Data Transfer Object to use in ListWorkbooksView / Activity and callbacks.
  * @author ltromel
  */
 @ToString
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/package-info.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/package-info.java
index 29c3233d..52766fb7 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/package-info.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/shared/dto/package-info.java
@@ -16,6 +16,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 /**
- * DTO : data transferts object between Services on server and GWT Client.
+ * DTO : data transfers object between Services on server and GWT Client.
  */
 package fr.soeretempo.sido.gwt.shared.dto;
diff --git a/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/client/resources/SidoConstants_fr.properties b/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/client/resources/SidoConstants_fr.properties
index 85b35af6..b4be107c 100644
--- a/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/client/resources/SidoConstants_fr.properties
+++ b/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/client/resources/SidoConstants_fr.properties
@@ -33,7 +33,7 @@ credits=Crédits
 #verification page
 consistencyWorkbook=La cohérence entre les données des classeurs n’est pas assurée par l’application.
 errorsWorkbook=Un ou plusieurs classeurs n’ont pas été insérés, voici les erreurs rencontrées\u00a0:
-valideWorkbook=Le ou les classeurs ont été insérés
+validWorkbook=Le ou les classeurs ont été insérés
 noWorkbook=Aucun classeur sélectionné ou classeur(s) invalide(s) (formats attendus\u00a0: .xlsx, .xls)
 processing=Traitement en cours, cela peut prendre quelques minutes…
 
@@ -156,7 +156,7 @@ datasetCreated=Jeu de données créé
 somethingWrongLoadingDatasource=Une erreur s’est produite en chargeant la source de données, SIDO va recharger
 datasourceManagers=Gestionnaires
 datasourceManager=Gestionnaire de la source
-noEmailAdress=Courriel inconnu
+noEmailAddress=Courriel inconnu
 manageDatasetUsers=Gestion des comptes
 email=Adresse courriel
 managing=Gestion de\u00a0:
diff --git a/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/server/resources/messages.properties b/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/server/resources/messages.properties
index 8fdc8c74..f0ffa74d 100644
--- a/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/server/resources/messages.properties
+++ b/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/server/resources/messages.properties
@@ -117,13 +117,13 @@ msgDatasetNotDraft=This dataset has status "{0}". You can add new files to a dat
 msgExcelDownloadProblem=File [{0}] not found, download problem, please contact the site administrator.
 
 # download file(.XML, .XLSX)
-msgDowloadFileProblem=File not found, please contact the site administrator.
+msgDownloadFileProblem=File not found, please contact the site administrator.
 
 #mail error
 sidoErrorSubject=SIDO - Error
 sidoErrorBody={0} - SIDO encountered an error:\n\
 {1}\n\n\
-Additionnal infos :\n\
+Additional infos :\n\
 {2}\n\
 --\n\
 {3}
diff --git a/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/server/resources/messages_fr.properties b/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/server/resources/messages_fr.properties
index 603bfff1..2edc8ad1 100644
--- a/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/server/resources/messages_fr.properties
+++ b/sido-gwt/src/main/resources/fr/soeretempo/sido/gwt/server/resources/messages_fr.properties
@@ -34,7 +34,7 @@ wrongFormat=Le fichier semble ne pas être au bon format.
 releaseNotes=Notes de version
 noMailAddress=Pas d’adresse courriel
 
-legalNoticesAndTermesOfUse=Mentions légales et conditions d\u2019utilisation
+legalNoticesAndTermesOfUse=Mentions légales et conditions d’utilisation
 
 msgChekEnumValues=Des valeurs de la colonne [ {0} ] de la feuille [ {3} ] ne correspondent pas aux valeurs prédéfinies {1}. Veuillez vérifier les lignes {2}.
 msgChekEnumValues[none]=Une valeur de la colonne [ {0} ] de la feuille [ {3} ] ne correspond pas aux valeurs prédéfinies {1}. Veuillez vérifier la ligne {2}.
@@ -116,7 +116,7 @@ msgDatasetNotDraft=Ce jeu de données est au statut "{0}". Vous pouvez ajouter d
 msgExcelDownloadProblem=Fichier [ {0} ] introuvable, problème du téléchargement. Veuillez contacter l’administrateur du site.
 
 # download file(.XML, .XLSX)
-msgDowloadFileProblem=Fichier introuvable. Veuillez contacter l’administrateur du site.
+msgDownloadFileProblem=Fichier introuvable. Veuillez contacter l’administrateur du site.
 
 #mail error
 sidoErrorSubject=SIDO - Erreur
@@ -233,3 +233,22 @@ printText=Imprimer cette page
 mailConfirmationTitle=Confirmez votre adresse courriel pour SIDO
 mailConfirmationBodyStart=Vous avez demandé à changer votre adresse courriel sur SIDO. Veuillez cliquer sur le lien suivant pour confirmer votre nouvelle adresse courriel.\n\n
 mailConfirmationBodyEnd=\n\nSi vous n’êtes pas à l’origine de cette requête, veuillez contacter l’équipe d’administration de SIDO.\n
+
+emailAccountDeletedNoAdressSubject=SIDO : Suppression prochaine de compte inactif sans adresse courriel
+emailAccountDeletedNoAdressBody=Le compte %s sera supprimé le %s pour inactivité, mais ne possède aucune adresse courriel associée.
+emailReminderAccountDeletionSubject=SIDO : Suppression prochaine de compte inactif
+emailReminderAccountDeletionBody=Bonjour %s,\
+\n\n\
+Vous recevez ce courriel parce que votre adresse électronique est liée à un compte sur SIDO. \
+Nous avons remarqué que vous n’avez pas eu d’activité sur SIDO depuis un long moment.\n\
+La période d’inactivité d’un compte est de deux ans, au delà de quoi, en accord avec le règlement du site, vos données personnelles seront supprimées. \
+D’ici deux semaines, le %s, sans action de votre part, votre compte sera supprimé, et les informations associées ne seront plus accessibles, et ne pourront pas être récupérées.\n\
+Vous souhaitez conservez votre accès à SIDO ? Il suffit de vous reconnecter : %s
+emailAccountDeletedSubject=SIDO : Suppression du compte inactif
+emailAccountDeletedBody=Bonjour %s,\
+\n\n\
+Vous recevez ce courriel parce que votre adresse électronique est liée à un compte sur SIDO : %s.\n\
+Comme annoncé dans un précédent courriel, la période d’inactivité d’un compte sur SIDO est de deux ans, au delà de quoi, en accord avec le règlement du site, nous nous sommes engagés à supprimer vos données personnelles.\n\
+Vous ne vous êtes pas connecté depuis le %s. \
+Votre compte a été supprimé, et les informations associées ne sont plus accessibles, et ne peuvent pas être récupérées.\n\
+Si vous avez des questions, répondez à cette adresse : support-tempo@inrae.fr
diff --git a/verification/src/main/java/fr/soeretempo/sido/verification/OutilsVerifXML.java b/verification/src/main/java/fr/soeretempo/sido/verification/OutilsVerifXML.java
index 303c0d6f..fcf8563b 100644
--- a/verification/src/main/java/fr/soeretempo/sido/verification/OutilsVerifXML.java
+++ b/verification/src/main/java/fr/soeretempo/sido/verification/OutilsVerifXML.java
@@ -191,7 +191,7 @@ public class OutilsVerifXML {
             final String sheet, final String schemaName)
                     throws IllegalArgumentException, JAXBException {
         final StringJoiner cols = new StringJoiner(", ");
-        if (listIgnorSheet().contains(sheet)) {
+        if (getIgnoredSheets().contains(sheet)) {
             throw new IllegalArgumentException(
                     "No data, the sheet \"" + sheet
                     + "\" is marked as ignored.");
@@ -259,7 +259,7 @@ public class OutilsVerifXML {
         final WorkbookXML fichP = workbookXML;
         final int indexFeuille = getSheetIndex(sheett);
         final List<WorksheetXML> sheets = fichP.getWorksheet();
-        if (!listIgnorSheet().contains(sheets.get(indexFeuille).getName())) {
+        if (!getIgnoredSheets().contains(sheets.get(indexFeuille).getName())) {
             sheets.get(indexFeuille).getFieldNameXML()
             .forEach((col) -> columns.add(col.getName().trim()));
         }
@@ -281,7 +281,7 @@ public class OutilsVerifXML {
         final WorkbookXML fichP = workbookXML;
         final int indexFeuille = getSheetIndex(sheett);
         final List<WorksheetXML> lstFP = fichP.getWorksheet();
-        if (!listIgnorSheet().contains(lstFP.get(indexFeuille).getName())) {
+        if (!getIgnoredSheets().contains(lstFP.get(indexFeuille).getName())) {
             return lstFP.get(indexFeuille).getFieldNameXML().stream()
                     .map(fieldName -> fieldName.getFieldType().getValue())
                     .collect(Collectors.joining(","));
@@ -295,7 +295,7 @@ public class OutilsVerifXML {
      * @throws JAXBException
      *             Exception JAXB
      */
-    public final List<String> listIgnorSheet() throws JAXBException {
+    public final List<String> getIgnoredSheets() throws JAXBException {
         final List<String> listIt = new ArrayList<>();
         final int workSheetSize = workbookXML.getWorksheet().size();
         for (int i = 0; i < workSheetSize; i++) {
@@ -312,7 +312,7 @@ public class OutilsVerifXML {
      * @throws JAXBException
      *             Exception JAXB
      */
-    public final List<String> listNotIgnorSheet() throws JAXBException {
+    public final List<String> getNotIgnoredSheets() throws JAXBException {
         final List<String> listIt = new ArrayList<>();
         final int workSheetSize = workbookXML.getWorksheet().size();
         for (int i = 0; i < workSheetSize; i++) {
@@ -390,7 +390,7 @@ public class OutilsVerifXML {
      * @throws JAXBException
      *             Exception JAXB
      */
-    public final List<String> listNotIgnorSheetBDD() throws JAXBException {
+    public final List<String> getDbTableNamesOfNotIgnoredSheets() throws JAXBException {
         final List<String> listIt = new ArrayList<>();
         final int workSheetSize = workbookXML.getWorksheet().size();
         for (int i = 0; i < workSheetSize; i++) {
@@ -484,7 +484,7 @@ public class OutilsVerifXML {
      * @throws JAXBException
      *             JAXB exception
      */
-    public final String validMissingVAlueXMLFile() {
+    public final String validMissingValueInXmlLFile() {
         String missingValueErr = null;
         final List<String> listMissingValue = Arrays.asList("yes", "no", "y/n");
         String lgn = null;
@@ -536,7 +536,7 @@ public class OutilsVerifXML {
      * @throws JAXBException
      *             JAXB exception
      */
-    public final String validUniqueVAlueXMLFile() throws JAXBException {
+    public final String validUniqueValueInXmlFile() throws JAXBException {
         String uniqueErr = null;
         final List<String> listUniqueValue = Arrays.asList("yes", "no");
         String lgn = null;
@@ -573,9 +573,9 @@ public class OutilsVerifXML {
                 || workbookXML.getSchemaNameBD() == null
                 || validWorkSheetAttributes() != null
                 || validFieldNames() != null
-                || validMissingVAlueXMLFile() != null
+                || validMissingValueInXmlLFile() != null
                 || validTypeValuesXMLFile() != null
-                || validUniqueVAlueXMLFile() != null
+                || validUniqueValueInXmlFile() != null
                 || validTagNameXMLFile() != null
                 || !isTypeEnum()) {
             return false;
@@ -583,10 +583,6 @@ public class OutilsVerifXML {
         return true;
     }
 
-    /* TODO faire une fonction pour
-     * retourner une erreur quand
-     * un fieldtype n'est pas rempli.*/
-
     /**
      * Check if every worksheet has a tableNameBD and name attribute, then if they are correctly spelled.
      * @return error list
diff --git a/verification/src/main/java/fr/soeretempo/sido/verification/Verification.java b/verification/src/main/java/fr/soeretempo/sido/verification/Verification.java
index 8e88add5..ae901937 100644
--- a/verification/src/main/java/fr/soeretempo/sido/verification/Verification.java
+++ b/verification/src/main/java/fr/soeretempo/sido/verification/Verification.java
@@ -380,7 +380,7 @@ public final class Verification extends OutilsVerif implements AutoCloseable {
      */
     public List<String> verifColumns(final String sheetName) throws InvalidFormatException, JAXBException {
         errors.clear();
-        final List<String> ignoredSheets = outilsVerifXML.listIgnorSheet();
+        final List<String> ignoredSheets = outilsVerifXML.getIgnoredSheets();
         if (!ignoredSheets.contains(sheetName) && outilsVerifXML.listSheetP().contains(sheetName)) {
             final int indexOfSheet = outilsVerifXML.getSheetIndex(sheetName);
             final int excelSheetColumnCount = outilsVerifExcel.getExcelHeaderRowLength(sheetName);
@@ -458,7 +458,7 @@ public final class Verification extends OutilsVerif implements AutoCloseable {
             final WorkbookXML fichP = outilsVerifXML.getWorkbookXML();
             List<String> listIt = new ArrayList<>();
             List<String> listSheetIgnored = new ArrayList<>();
-            listSheetIgnored = outilsVerifXML.listIgnorSheet();
+            listSheetIgnored = outilsVerifXML.getIgnoredSheets();
             // index of the sheet in XML file
             final int indexSheet = outilsVerifXML.getSheetIndex(sheett);
             boolean err = false;
@@ -630,7 +630,7 @@ public final class Verification extends OutilsVerif implements AutoCloseable {
             errors.clear();
             final WorkbookXML param = outilsVerifXML.getWorkbookXML();
             String sheetName = "";
-            final List<String> listSheetIgnored = outilsVerifXML.listIgnorSheet();
+            final List<String> listSheetIgnored = outilsVerifXML.getIgnoredSheets();
             final int startLine = outilsVerifXML.startLine();
             String lgn = null;
             String sheetMissing = "";
@@ -773,12 +773,12 @@ public final class Verification extends OutilsVerif implements AutoCloseable {
      */
     public boolean startLineError() throws JAXBException {
         final int startline = outilsVerifXML.startLine();
-        LOGGER.trace("list ignored sheet " + outilsVerifXML.listIgnorSheet());
+        LOGGER.trace("list ignored sheet " + outilsVerifXML.getIgnoredSheets());
         for (int i = 0; i < outilsVerifXML.listSheetP().size(); i++) {
             final String xmlSheetName = outilsVerifXML.listSheetP().get(i);
-            if (outilsVerifXML.listNotIgnorSheetBDD().contains(xmlSheetName)) {
+            if (outilsVerifXML.getDbTableNamesOfNotIgnoredSheets().contains(xmlSheetName)) {
                 final int nbrRow = outilsVerifExcel.getLastRowNumber(outilsVerifExcel.listExcelSheetNames().get(i));
-                if (!outilsVerifXML.listIgnorSheet().contains(xmlSheetName) && nbrRow + 1 < startline) {
+                if (!outilsVerifXML.getIgnoredSheets().contains(xmlSheetName) && nbrRow + 1 < startline) {
                     LOGGER.error("startLineError true in {} : {} > {}", xmlSheetName, startline, nbrRow + 1);
                     return true;
                 }
diff --git a/verification/src/main/resources/fr/soeretempo/sido/verification/resources/messages.properties b/verification/src/main/resources/fr/soeretempo/sido/verification/resources/messages.properties
index 29d12b39..d2a82fc1 100644
--- a/verification/src/main/resources/fr/soeretempo/sido/verification/resources/messages.properties
+++ b/verification/src/main/resources/fr/soeretempo/sido/verification/resources/messages.properties
@@ -34,7 +34,7 @@ msgColumnNotPresentAsExpected=Check your sheet {0}, a column is not provided in
 msgConfigPropProblem=Unable to load the file "config.properties", please contact the site administrator.
 msgDeleteWorkbookProblem=Unable to delete the workbook, please contact the site administrator.
 msgDeleteWorkbook=The workbook is deleted.
-msgDowloadFileProblem=File not found, please contact the site administrator.
+msgDownloadFileProblem=File not found, please contact the site administrator.
 msgExcelDownloadProblem=File [ {0} ] not found, download problem, please contact the site administrator.
 msgFormatDate[none]=The dates in column [ {0} ] must respect the format [ {1} ]. Please check line {2} on sheet [ {3} ].
 msgFormatDate=The dates in column [ {0} ] must respect the format [ {1} ]. Please check lines {2} on sheet [ {3} ].
diff --git a/verification/src/main/resources/fr/soeretempo/sido/verification/resources/messages_fr.properties b/verification/src/main/resources/fr/soeretempo/sido/verification/resources/messages_fr.properties
index 9667fdda..e2c59ed6 100644
--- a/verification/src/main/resources/fr/soeretempo/sido/verification/resources/messages_fr.properties
+++ b/verification/src/main/resources/fr/soeretempo/sido/verification/resources/messages_fr.properties
@@ -110,7 +110,7 @@ verifWorkbook=Ceci n’est pas un classeur Excel
 msgExcelDownloadProblem=Fichier [ {0} ] introuvable, échec du téléchargement vers le serveur. Veuillez contacter l’administrateur du site.
 
 # download file(.XML, .XLSX)
-msgDowloadFileProblem=Fichier introuvable. Veuillez contacter l’administrateur du site.
+msgDownloadFileProblem=Fichier introuvable. Veuillez contacter l’administrateur du site.
 
 #mail insertion
 subjectMailInsert=SIDO - nouvelle insertion d’un classeur dans la source de données « {0} »
diff --git a/verification/src/test/java/fr/soeretempo/sido/verification/OutilsVerifXMLTest.java b/verification/src/test/java/fr/soeretempo/sido/verification/OutilsVerifXMLTest.java
index f72be5df..4a170263 100644
--- a/verification/src/test/java/fr/soeretempo/sido/verification/OutilsVerifXMLTest.java
+++ b/verification/src/test/java/fr/soeretempo/sido/verification/OutilsVerifXMLTest.java
@@ -200,7 +200,7 @@ public class OutilsVerifXMLTest {
      */
     @Test
     public void validMissingValuesXMLFileTest() throws JAXBException {
-        final String actual = verifXMLTest.validMissingVAlueXMLFile();
+        final String actual = verifXMLTest.validMissingValueInXmlLFile();
         final String result = "ynes, y";
         assertEquals(result, actual);
     }
@@ -231,7 +231,7 @@ public class OutilsVerifXMLTest {
      */
     @Test
     public void validUniqueValuesXMLFileTest() throws JAXBException {
-        final String actual = verifXMLTest.validUniqueVAlueXMLFile();
+        final String actual = verifXMLTest.validUniqueValueInXmlFile();
         final String result = "non, n";
         assertEquals(result, actual);
     }
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/datasetadmin/DatasetAdminModal.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/datasetadmin/DatasetAdminModal.java
index 57d8aeeb..c265911a 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/datasetadmin/DatasetAdminModal.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/datasetadmin/DatasetAdminModal.java
@@ -155,7 +155,7 @@ public final class DatasetAdminModal extends Composite {
     }
 
     /**
      * Map of addableUsers for the oracle. The key is the display name and adress,
      *  and the value is the DTO associated.
      */
     private final Map<String, UserDTO> addableUsers = new HashMap<>();
@@ -195,7 +195,7 @@ public final class DatasetAdminModal extends Composite {
             if (user.getEmail() != null && !user.getEmail().isEmpty()) {
                 text.append("(").append(user.getEmail()).append(")");
             } else {
-                text.append("(").append(constants.noEmailAdress()).append(")");
+                text.append("(").append(constants.noEmailAddress()).append(")");
             }
             // Put the user in the map
             addableUsers.put(text.toString(), user);
@@ -228,7 +228,7 @@ public final class DatasetAdminModal extends Composite {
         tableColumnBuilder.addTextColumn(constants.userName(), user -> user.getName());
         tableColumnBuilder.addTextColumn(constants.email(), user -> {
             if (user.getEmail() == null || user.getEmail().isEmpty()) {
-                return constants.noEmailAdress();
+                return constants.noEmailAddress();
             }
             return user.getEmail();
         });
@@ -155,7 +155,7 @@ public final class DatasetAdminModal extends Composite {
 
     /**
-     * Map of addableUsers for the oracle. The key is the display name and adress,
+     * Map of addableUsers for the oracle. The key is the display name and address,
      *  and the value is the DTO associated.
      */
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/datasourceadmin/DatasourceAdminModal.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/datasourceadmin/DatasourceAdminModal.java
index f4e774f2..07a135ec 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/datasourceadmin/DatasourceAdminModal.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/client/managedatasource/datasourceadmin/DatasourceAdminModal.java
@@ -144,7 +144,7 @@ public final class DatasourceAdminModal extends Composite {
     }
 
     /**
      * Map of addableUsers for the oracle. The key is the display name and adress,
      *  and the value is the DTO associated.
      */
     private final Map<String, UserDTO> addableUsers = new HashMap<>();
@@ -184,7 +184,7 @@ public final class DatasourceAdminModal extends Composite {
             if (user.getEmail() != null && !user.getEmail().isEmpty()) {
                 text.append("(").append(user.getEmail()).append(")");
             } else {
-                text.append("(").append(constants.noEmailAdress()).append(")");
+                text.append("(").append(constants.noEmailAddress()).append(")");
             }
             // Put the user in the map
             addableUsers.put(text.toString(), user);
@@ -217,7 +217,7 @@ public final class DatasourceAdminModal extends Composite {
         tableColumnBuilder.addTextColumn(constants.userName(), user -> user.getName());
         tableColumnBuilder.addTextColumn(constants.email(), user -> {
             if (user.getEmail() == null || user.getEmail().isEmpty()) {
-                return constants.noEmailAdress();
+                return constants.noEmailAddress();
             }
             return user.getEmail();
         });
@@ -144,7 +144,7 @@ public final class DatasourceAdminModal extends Composite {
 
     /**
-     * Map of addableUsers for the oracle. The key is the display name and adress,
+     * Map of addableUsers for the oracle. The key is the display name and address,
      *  and the value is the DTO associated.
      */
diff --git a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/mail/MailService.java b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/mail/MailService.java
index 96897551..8eaa2cf0 100644
--- a/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/mail/MailService.java
+++ b/sido-gwt/src/main/java/fr/soeretempo/sido/gwt/server/mail/MailService.java
@@ -210,9 +210,9 @@ public class MailService {
             // If the desired charset is known, you can use setText(text, charset)
             msg.setContent(mail.getMessage(), mail.getFullMimeType());
 
-            if (!mail.getAttachements().isEmpty()) {
-                final List<String> attachements = mail.getAttachements();
-                LOGGER.debug(attachements.size());
+            if (!mail.getAttachments().isEmpty()) {
+                final List<String> attachments = mail.getAttachments();
+                LOGGER.debug(attachments.size());
                 // Create the message part
                 BodyPart messageBodyPart = new MimeBodyPart();
 
@@ -223,10 +223,10 @@ public class MailService {
                 // Set text message part
                 multipart.addBodyPart(messageBodyPart);
 
-                for (final String attachement : attachements) {
+                for (final String attachment : attachments) {
                     // Part two is attachment
                     messageBodyPart = new MimeBodyPart();
-                    final String filename = attachement;
+                    final String filename = attachment;
                     final DataSource source = new FileDataSource(filename);
                     messageBodyPart.setDataHandler(new DataHandler(source));
                     messageBodyPart.setFileName(filename);
@@ -263,7 +263,7 @@ public class MailService {
                         for (final Address element : invalid) {
                             messageException.append(element).append(" ");
                         }
-                        throw new SendMailException("send : Invalid Adresses : "
+                        throw new SendMailException("send : Invalid Addresses : "
                                 + messageException.toString());
                     }
 
@@ -274,7 +274,7 @@ public class MailService {
                             messageException.append(element).append(" ");
                         }
                         throw new SendMailException(ex,
-                                "send : Valid Unsent Adresses : "
+                                "send : Valid Unsent Addresses : "
                                         + messageException.toString());
                     }
 
@@ -395,11 +395,11 @@ public class MailService {
      * Send a mail to admin team showing an error the application has thrown.
      * @param error Throwable
      * @param applicationUrl current instance url
      * @param additionnalInfos more infos about the error
      * @throws SendMailException
      */
     public void errorMail(final Throwable error,
-            final String applicationUrl, final String additionnalInfos) {
+            final String applicationUrl, final String additionalInfos) {
         LOGGER.traceEntry();
         final StringWriter sw = new StringWriter();
         final PrintWriter pw = new PrintWriter(sw);
@@ -408,7 +408,7 @@ public class MailService {
             final DateTimeFormatter dtf = DateTimeFormatter.ofPattern("dd/MM/yyyy HH:mm");
             send(new Mail(adminI18n.format("sidoErrorSubject"),
                     adminI18n.format("sidoErrorBody",
-                            dtf.format(LocalDateTime.now()), sw.toString(), additionnalInfos, applicationUrl)));
+                            dtf.format(LocalDateTime.now()), sw.toString(), additionalInfos, applicationUrl)));
         } catch (final SendMailException e) {
             LOGGER.error("Couldn't send mail !");
             LOGGER.catching(e);
@@ -417,12 +417,13 @@ public class MailService {
     }
 
     /**
      * Constructs additionnal infos to be given with a mail for more context.
      * @param dataset
      * @param user
      * @return concatenated additionnal context infos
      */
-    public String getAdditionnalInfos(final Dataset dataset, final User user) {
+    // TODO : remove this method from this class
+    public String getAdditionalInfos(final Dataset dataset, final User user) {
         final StringJoiner sj = new StringJoiner("\n");
         if (dataset != null) {
             sj.add("Source ID : " + dataset.getDatasource().getId())
@@ -606,8 +607,8 @@ public class MailService {
         if (account.getEmail() == null) {
             LOGGER.info("This account : " + account.toString() + "has no email address.");
             try {
-                send(new Mail(adminI18n.format("emailAccountDeletionNoAdressSubject"),
-                        String.format(adminI18n.format("emailAccountDeletionNoAdressBody"),
+                send(new Mail(adminI18n.format("emailAccountDeletionNoAddressSubject"),
+                        String.format(adminI18n.format("emailAccountDeletionNoAddressBody"),
                                 account.toString(), sdt.format(fourteenDays), applicationURL)));
             } catch (final SendMailException e) {
                 LOGGER.catching(e);
@@ -641,8 +642,8 @@ public class MailService {
         if (account.getEmail() == null) {
             LOGGER.info("This account : " + account.toString() + "has no email address.");
             try {
-                send(new Mail(adminI18n.format("emailAccountDeletedNoAdressSubject"),
-                        String.format(adminI18n.format("emailAccountDeletedNoAdressBody"),
+                send(new Mail(adminI18n.format("emailAccountDeletedNoAddressSubject"),
+                        String.format(adminI18n.format("emailAccountDeletedNoAddressBody"),
                                 account.toString(), sdt.format(fourteenDays), applicationURL)));
             } catch (final SendMailException e) {
                 LOGGER.catching(e);
@@ -395,11 +395,11 @@ public class MailService {
      * @param error Throwable
      * @param applicationUrl current instance url
-     * @param additionnalInfos more infos about the error
+     * @param additionalInfos more infos about the error
      * @throws SendMailException
      */
@@ -417,12 +417,13 @@ public class MailService {
 
     /**
-     * Constructs additionnal infos to be given with a mail for more context.
+     * Constructs additional infos to be given with a mail for more context.
      * @param dataset
      * @param user
@@ -417,12 +417,13 @@ public class MailService {
      * @param dataset
      * @param user
-     * @return concatenated additionnal context infos
+     * @return concatenated additional context infos
      */
-- 
GitLab